
Expleo ATP (Automation Test Proxy) Robot Framework library used to execute remote test commands (click, keyword) on low level agents, that are running the ATP server component.

ATPLibrary supports standard and relay mode, to utilize either a Sikuli instance on the agent, or in cases where Sikuli cannot be installed, then relay click by image to a relay instance of Sikuli.

[Git Project repo can be found here](https://sqsglobal.visualstudio.com/ATP/_git/ATP.RobotFramework)